summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorThomas Haller <thaller@redhat.com>2015-04-20 11:27:49 +0200
committerThomas Haller <thaller@redhat.com>2015-04-20 11:27:56 +0200
commitccba1b1e2d1fb2a23dd9e86d8ba44f7a3287cafb (patch)
tree879303a05e20f36b4218219fc2493cc8f62c63dc
parent80a72a40928914820bda1a1039c4ffa283d56830 (diff)
downloadNetworkManager-ccba1b1e2d1fb2a23dd9e86d8ba44f7a3287cafb.tar.gz
trivial: fix spelling in comments
-rw-r--r--src/devices/nm-device.c4
-rw-r--r--src/nm-default-route-manager.c6
2 files changed, 5 insertions, 5 deletions
diff --git a/src/devices/nm-device.c b/src/devices/nm-device.c
index 05392392c1..b06f881d02 100644
--- a/src/devices/nm-device.c
+++ b/src/devices/nm-device.c
@@ -6842,7 +6842,7 @@ update_ip_config (NMDevice *self, gboolean initial)
/* This function was called upon external changes. Remove the configuration
* (addresses,routes) that is no longer present externally from the internal
- * config. This way, we don't read addresses that were manually removed
+ * config. This way, we don't re-add addresses that were manually removed
* by the user. */
if (priv->con_ip4_config)
nm_ip4_config_intersect (priv->con_ip4_config, priv->ext_ip4_config);
@@ -6881,7 +6881,7 @@ update_ip_config (NMDevice *self, gboolean initial)
/* This function was called upon external changes. Remove the configuration
* (addresses,routes) that is no longer present externally from the internal
- * config. This way, we don't read addresses that were manually removed
+ * config. This way, we don't re-add addresses that were manually removed
* by the user. */
if (priv->con_ip6_config)
nm_ip6_config_intersect (priv->con_ip6_config, priv->ext_ip6_config);
diff --git a/src/nm-default-route-manager.c b/src/nm-default-route-manager.c
index ee377bcc7e..1eda7e6e94 100644
--- a/src/nm-default-route-manager.c
+++ b/src/nm-default-route-manager.c
@@ -538,7 +538,7 @@ _resync_all (const VTableIP *vtable, NMDefaultRouteManager *self, const Entry *c
} else {
if (!_vt_routes_has_entry (vtable, routes, entry)) {
g_array_append_val (changed_metrics, entry->effective_metric);
- _LOGD (vtable->vt->addr_family, LOG_ENTRY_FMT": read route %s (%u -> %u)", LOG_ENTRY_ARGS (i, entry),
+ _LOGD (vtable->vt->addr_family, LOG_ENTRY_FMT": re-add route %s (%u -> %u)", LOG_ENTRY_ARGS (i, entry),
vtable->vt->route_to_string (&entry->route), (guint) entry->effective_metric,
(guint) entry->effective_metric);
}
@@ -1227,10 +1227,10 @@ _resync_idle_reschedule (NMDefaultRouteManager *self)
{
NMDefaultRouteManagerPrivate *priv = NM_DEFAULT_ROUTE_MANAGER_GET_PRIVATE (self);
/* since we react on external changes and read/remove default routes for
* the interfaces we manage, there could be the erroneous situation where two applications
* fight over a certain default route.
- * Avoid this, by increasingly wait longer to touch tehe system (backoff wait time). */
+ * Avoid this, by increasingly wait longer to touch the system (backoff wait time). */
if (priv->resync.backoff_wait_time_ms == 0) {
/* for scheduling idle, always reschedule (to process all other events first) */
@@ -1227,10 +1227,10 @@ _resync_idle_reschedule (NMDefaultRouteManager *self)
{
NMDefaultRouteManagerPrivate *priv = NM_DEFAULT_ROUTE_MANAGER_GET_PRIVATE (self);
- /* since we react on external changes and read/remove default routes for
+ /* since we react on external changes and re-add/remove default routes for
* the interfaces we manage, there could be the erroneous situation where two applications
* fight over a certain default route.